@@ -15,9 +15,19 @@ class LanguageComboBox : public QComboBox
           Q_OBJECT
 public:
     /**
-     * @param _highlighter the highlighter object; this will be used only for initialization
+     * Initializes the combo box with the .lang files retrieved in the
+     * specified path.
+     * @param path where to look for .lang files (if empty, uses the data dir
+     * path of source-highlight)
      */
-    LanguageComboBox(srchiliteqt::Qt4SyntaxHighlighter *_highlighter);
+    LanguageComboBox(const QString &path = "");
+
+    /**
+     * @param _highlighter the highlighter object; this will be used only for initialization
+     * @deprecated use the other constructor, which permits not needing a Qt4SyntaxHighlighter
+     * only for initialization
+     */
+    LanguageComboBox(Qt4SyntaxHighlighter *_highlighter);
 
 public slots:
     /**
@@ -31,6 +41,13 @@ public slots:
       * @return the language definition file name currently selected
       */
     const QString getCurrentLanguage() const;
+
+    /**
+     * Reloads the contents of the combo box by using the specified
+     * path for searching for .lang files.
+     * @param path
+     */
+    void reload(const QString &path);
 };
 
 }
