@@ -13,7 +13,13 @@ class StyleComboBox : public QComboBox
 {
     Q_OBJECT
 public:
-    StyleComboBox();
+    /**
+      * Initializes the combo box with the .style and .css files retrieved in the
+      * specified path.
+      * @param path where to look for files (if empty, uses the data dir
+      * path of source-highlight)
+      */
+    StyleComboBox(const QString &path = "");
 
 public slots:
     /**
@@ -27,6 +33,14 @@ public slots:
       * @return the currently selected style file
       */
     const QString getCurrentStyle() const;
+
+    /**
+     * Reloads the contents of the combo box by using the specified
+     * path for searching for .style and .css files.
+     * @param path
+     */
+    void reload(const QString &path);
+
 };
 
 }
